@@ -8,7 +8,6 @@ import functools
 import logging
 import uuid
 
-import six
 import uamqp
 from uamqp import c_uamqp, constants, errors, utils
 
@@ -89,10 +88,10 @@ class MessageReceiver(object):
                  desired_capabilities=None):
         # pylint: disable=protected-access
         if name:
-            self.name = name.encode(encoding) if isinstance(name, six.text_type) else name
+            self.name = name.encode(encoding) if isinstance(name, str) else name
         else:
             self.name = str(uuid.uuid4()).encode(encoding)
-        target = target.encode(encoding) if isinstance(target, six.text_type) else target
+        target = target.encode(encoding) if isinstance(target, str) else target
         role = constants.Role.Receiver
 
         self.source = source._address.value
